@@ -4,7 +4,7 @@ cross_validate <- function(corpus,nfold,algorithm=c("SVM","SLDA","BOOSTING","BAG
 							maxitglm=500, # GLMNET PARAMETERS
 							size=1,maxitnnet=1000,MaxNWts=10000,rang=0.1,decay=5e-4, # NNET PARAMETERS
 							ntree=200, # RF PARAMETERS
-							feature_cutoff=0,gaussian_prior=0,inequality_constraints=0 # MAXENT PARAMETERS
+							l1_regularizer=0.0,l2_regularizer=0.0,use_sgd=FALSE,set_heldout=0,verbose=FALSE # MAXENT PARAMETERS
 							) {
 
     options(warn=-1) #Supress warnings
@@ -80,7 +80,7 @@ cross_validate <- function(corpus,nfold,algorithm=c("SVM","SLDA","BOOSTING","BAG
             pred <- apply(prob,1,which.max)
         } else
 		if (algorithm=="MAXENT") {
-			model <- maxent(corpus@training_matrix,as.vector(corpus@training_codes),feature_cutoff=feature_cutoff,gaussian_prior=gaussian_prior,inequality_constraints=inequality_constraints)
+			model <- maxent(corpus@training_matrix,as.vector(corpus@training_codes),l1_regularizer,l2_regularizer,use_sgd,set_heldout,verbose)
 			pred <- predict(model,alldata[rand==i,])
 			pred <- pred[,1]
 		}
